==> tuia-advert-center-api-2.5.62-sources.jar: cn/com/duiba/tuia/core/api/dto/advert/req/ReqPageQueryAdvertInfoDto.java <==
package cn.com.duiba.tuia.core.api.dto.advert.req;

import cn.com.duiba.tuia.core.api.statistics.domain.BaseQueryReq;

import java.util.Date;
import java.util.List;

/**
 * Created by huangch on 2017/8/25 10:05
 * description:
 *
 * @since JDK 1.6
 */
public class ReqPageQueryAdvertInfoDto extends BaseQueryReq {

    private static final long serialVersionUID = 3241638193765717369L;

    /**
     * 广告ID
     */
    private Long advertId;

    //广告类型 1-互动广告、2-展示广告
    private Integer advertType;

    /**
     * 广告名称.
     */
    private String name;

    /**
     * 审核状态.
     */
    private Integer checkStatus;

    /**
     * 代理商类型(0：精易，1：其他)
     */
    private Integer agentType;

    /**
     * 代理商名称
     */
    private String agentCompanyName;

    /**
     * 广告主Ids
     */
    private List<Long> advertiserIds;

    /**
     * 兑吧广告ids
     */
    private List<Long> duibaIds;

    /** 广告id集合 */
    private List<Long> advertIds;

    private Integer abate;

    private Date startDate;

    private Date endDate;

    /**
     * 创新测试对于的广告主
     */
    private List<Long> testAccountIds;

    public Integer getAbate() {
        return abate;
    }

    public void setAbate(Integer abate) {
        this.abate = abate;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Integer getAdvertType() {
        return advertType;
    }

    public void setAdvertType(Integer advertType) {
        this.advertType = advertType;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Integer getCheckStatus() {
        return checkStatus;
    }

    public void setCheckStatus(Integer checkStatus) {
        this.checkStatus = checkStatus;
    }

    public Integer getAgentType() {
        return agentType;
    }

    public void setAgentType(Integer agentType) {
        this.agentType = agentType;
    }

    public String getAgentCompanyName() {
        return agentCompanyName;
    }

    public void setAgentCompanyName(String agentCompanyName) {
        this.agentCompanyName = agentCompanyName;
    }

    public List<Long> getDuibaIds() {
        return duibaIds;
    }

    public void setDuibaIds(List<Long> duibaIds) {
        this.duibaIds = duibaIds;
    }

    public List<Long> getAdvertIds() {
        return advertIds;
    }

    public void setAdvertIds(List<Long> advertIds) {
        this.advertIds = advertIds;
    }


    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    /**
     * advertiserIds.
     *
     * @return  the advertiserIds
     * @since   JDK 1.8
     */
    public List<Long> getAdvertiserIds() {
        return advertiserIds;
    }

    /**
     * advertiserIds.
     *
     * @param   advertiserIds    the advertiserIds to set
     * @since   JDK 1.8
     */
    public void setAdvertiserIds(List<Long> advertiserIds) {
        this.advertiserIds = advertiserIds;
    }


    public List<Long> getTestAccountIds() {
        return testAccountIds;
    }

    public void setTestAccountIds(List<Long> testAccountIds) {
        this.testAccountIds = testAccountIds;
    }
}

==> tuia-advert-center-api-2.6.27-sources.jar: cn/com/duiba/tuia/core/api/dto/advert/req/ReqPageQueryAdvertInfoDto.java <==
package cn.com.duiba.tuia.core.api.dto.advert.req;

import cn.com.duiba.tuia.core.api.statistics.domain.BaseQueryReq;

import java.util.Date;
import java.util.List;

/**
 * Created by huangch on 2017/8/25 10:05
 * description:
 *
 * @since JDK 1.6
 */
public class ReqPageQueryAdvertInfoDto extends BaseQueryReq {

    private static final long serialVersionUID = 3241638193765717369L;

    /**
     * 广告ID
     */
    private Long advertId;

    //广告类型 1-互动广告、2-展示广告
    private Integer advertType;

    /**
     * 广告名称.
     */
    private String name;

    /**
     * 审核状态.
     */
    private Integer checkStatus;

    /**
     * 代理商类型(0：精易，1：其他)
     */
    private Integer agentType;

    /**
     * 代理商名称
     */
    private String agentCompanyName;

    /**
     * 广告主Ids
     */
    private List<Long> advertiserIds;

    /**
     * 兑吧广告ids
     */
    private List<Long> duibaIds;

    /** 广告id集合 */
    private List<Long> advertIds;

    private Integer abate;

    private Date startDate;

    private Date endDate;

    /**
     * 创新测试对于的广告主
     */
    private List<Long> testAccountIds;

    /**
     * 0-正常 1-限流 null - 全部
     */
    private Integer circuitBreakFlag;

    public Integer getCircuitBreakFlag() {
        return circuitBreakFlag;
    }

    public void setCircuitBreakFlag(Integer circuitBreakFlag) {
        this.circuitBreakFlag = circuitBreakFlag;
    }

    public Integer getAbate() {
        return abate;
    }

    public void setAbate(Integer abate) {
        this.abate = abate;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Integer getAdvertType() {
        return advertType;
    }

    public void setAdvertType(Integer advertType) {
        this.advertType = advertType;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Integer getCheckStatus() {
        return checkStatus;
    }

    public void setCheckStatus(Integer checkStatus) {
        this.checkStatus = checkStatus;
    }

    public Integer getAgentType() {
        return agentType;
    }

    public void setAgentType(Integer agentType) {
        this.agentType = agentType;
    }

    public String getAgentCompanyName() {
        return agentCompanyName;
    }

    public void setAgentCompanyName(String agentCompanyName) {
        this.agentCompanyName = agentCompanyName;
    }

    public List<Long> getDuibaIds() {
        return duibaIds;
    }

    public void setDuibaIds(List<Long> duibaIds) {
        this.duibaIds = duibaIds;
    }

    public List<Long> getAdvertIds() {
        return advertIds;
    }

    public void setAdvertIds(List<Long> advertIds) {
        this.advertIds = advertIds;
    }


    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    /**
     * advertiserIds.
     *
     * @return  the advertiserIds
     * @since   JDK 1.8
     */
    public List<Long> getAdvertiserIds() {
        return advertiserIds;
    }

    /**
     * advertiserIds.
     *
     * @param   advertiserIds    the advertiserIds to set
     * @since   JDK 1.8
     */
    public void setAdvertiserIds(List<Long> advertiserIds) {
        this.advertiserIds = advertiserIds;
    }


    public List<Long> getTestAccountIds() {
        return testAccountIds;
    }

    public void setTestAccountIds(List<Long> testAccountIds) {
        this.testAccountIds = testAccountIds;
    }
}
